@@ -13,6 +13,7 @@ from qds_ops.entities.chef import Chef
 from qds_ops.entities.rds import RDS
 from qds_ops.entities.scheduler import Scheduler
 from qds_ops.entities.default_dj import DefaultDJ
+from qds_ops.entities.experimental_dj import ExperimentalDJ
 from qds_ops.utils import argparse
 from qds_ops import __version__
 from inflection import camelize
@@ -34,6 +35,7 @@ def main():
     rds = RDS(subparsers)
     scheduler = Scheduler(subparsers)
     defaultDJ = DefaultDJ(subparsers)
+    experimentalDJ = ExperimentalDJ(subparsers)
 
     args = argparser.parse_args()
     args.func(args)
