@@ -12,14 +12,14 @@ from qds_ops.entities.rds import RDS
 import requests
 
 class Scheduler(Tier):
-    def __init__(self, subparser):
-        self.tier = "scheduler"
-        self.ami_id = "ami-0598906c"
-        self.region = "us-east-1"
-        self.instance_type = "m1.large"
-        self.run_list = '{"run_list":["recipe[webslave::deploy_scheduler]"],"qubole_tier":"scheduler"}'
-        self.modules = ["scheduler"]
+    tier = "scheduler"
+    ami_id = "ami-0598906c"
+    region = "us-east-1"
+    instance_type = "m1.large"
+    run_list = '{"run_list":["recipe[webslave::deploy_scheduler]"],"qubole_tier":"scheduler"}'
+    modules = ["scheduler"]
 
+    def __init__(self, subparser):
         super(Scheduler, self).__init__(subparser)
 
         # Create
